/***************************************************************************
 * Functions to handle drawing buttons.
 * Copyright (C) 2004 Joe Wingbermuehle
 ***************************************************************************/

#include "jwm.h"

static Drawable drawable;
static GC gc;
static XFontStruct *font = NULL;
static int width, height;
static AlignmentType alignment;
static int brackets;
static int yoffset;

/***************************************************************************
 ***************************************************************************/
void SetButtonDrawable(Drawable d, GC g) {
	drawable = d;
	gc = g;
}

/***************************************************************************
 ***************************************************************************/
void SetButtonFont(XFontStruct *f) {

	Assert(f);

	font = f;
	yoffset = 1 + height / 2 - (font->ascent + font->descent) / 2;
}

/***************************************************************************
 ***************************************************************************/
void SetButtonSize(int w, int h) {
	width = w;
	height = h;
	if(font) {
		yoffset = 1 + height / 2 - (font->ascent + font->descent) / 2;
	}
}

/***************************************************************************
 ***************************************************************************/
void SetButtonAlignment(AlignmentType a) {
	alignment = a;
}

/***************************************************************************
 ***************************************************************************/
void SetButtonBrackets(int bb) {
	brackets = bb;
}

/***************************************************************************
 ***************************************************************************/
void DrawButton(int x, int y, ButtonType type, const char *str) {
	long outlinePixel;
	long topPixel, bottomPixel;
	RampType ramp;
	char *temp;
	int xoffset;
	int len;

	switch(type) {
	case BUTTON_ACTIVE:
		ramp = RAMP_BUTTON;
		outlinePixel = colors[COLOR_BUTTON_DOWN];
		topPixel = colors[COLOR_BUTTON_DOWN];
		bottomPixel = colors[COLOR_BUTTON_UP];
		break;
	case BUTTON_MENU:
		ramp = RAMP_ACTIVE;
		outlinePixel = colors[COLOR_ACTIVE_BORDER_DOWN];
		topPixel = colors[COLOR_ACTIVE_BORDER_UP];
		bottomPixel = colors[COLOR_ACTIVE_BORDER_DOWN];
		break;
	default: /* BUTTON_INACTIVE */
		ramp = RAMP_INACTIVE;
		outlinePixel = colors[COLOR_BORDER_DOWN];
		topPixel = colors[COLOR_BORDER_UP];
		bottomPixel = colors[COLOR_BORDER_DOWN];
		break;
	}

	JXSetForeground(display, gc, ramps[ramp][0]);
	JXFillRectangle(display, drawable, gc, x + 2, y + 2, width - 3, height - 3);

	JXSetForeground(display, gc, outlinePixel);
	JXDrawLine(display, drawable, gc, x + 1, y, x + width - 1, y);
	JXDrawLine(display, drawable, gc, x + 1, y + height, x + width - 1,
		y + height);
	JXDrawLine(display, drawable, gc, x, y + 1, x, y + height - 1);
	JXDrawLine(display, drawable, gc, x + width, y + 1, x + width,
		y + height - 1);

	JXSetForeground(display, gc, topPixel);
	JXDrawLine(display, drawable, gc, x + 1, y + 1, x + width - 2, y + 1);
	JXDrawLine(display, drawable, gc, x + 1, y + 2, x + 1, y + height - 2);

	JXSetForeground(display, gc, bottomPixel);
	JXDrawLine(display, drawable, gc, x + 1, y + height - 1, x + width - 1,
		y + height - 1);
	JXDrawLine(display, drawable, gc, x + width - 1, y + 1, x + width - 1,
		y + height - 2);

	if(str) {
		len = strlen(str);
	} else {
		len = 0;
	}

	if(brackets) {
		temp = Allocate(len + 3);
		temp[0] = '[';
		if(str) {
			strcpy(temp + 1, str);
		}
		temp[len + 1] = ']';
		temp[len + 2] = 0;
		if(alignment == ALIGN_CENTER) {
			xoffset = 1 + width / 2 - JXTextWidth(font, temp, len) / 2;
		} else {
			xoffset = 4;
		}
		RenderString(drawable, gc, font, ramp, x + xoffset, y + yoffset,
			width - 8, temp);
		Release(temp);
	} else if(len) {
		if(alignment == ALIGN_CENTER) {
			xoffset = 1 + width / 2 - JXTextWidth(font, str, len) / 2;
		} else {
			xoffset = 4;
		}
		RenderString(drawable, gc, font, ramp, x + xoffset, y + yoffset,
			width - 8, str);
	}

}

