/*************************************************************************
 * Functions for displaying window move/resize status.
 * Copyright (C) 2004 Joe Wingbermuehle
 *************************************************************************/

#include "jwm.h"

#define STATUS_WINDOW_WIDTH 128

static Window statusWindow;
static GC statusGC;
static unsigned int statusWindowHeight;

/*************************************************************************
 *************************************************************************/
void CreateMoveWindow() {
	XSetWindowAttributes attrs;
	int x, y;

	statusWindowHeight = borderFont->ascent + borderFont->descent + 4;

	x = rootWidth / 2 - STATUS_WINDOW_WIDTH / 2;
	y = rootHeight / 2 - statusWindowHeight / 2;

	attrs.background_pixel = colors[COLOR_BORDER];
	attrs.border_pixel = colors[COLOR_BORDER_OUTLINE];
	attrs.save_under = True;
	attrs.override_redirect = True;

	statusWindow = JXCreateWindow(display, rootWindow, x, y,
		STATUS_WINDOW_WIDTH, statusWindowHeight, 1,
		CopyFromParent, InputOutput, CopyFromParent,
		CWBackPixel | CWBorderPixel | CWOverrideRedirect | CWSaveUnder,
		&attrs);

	JXMapRaised(display, statusWindow);
	statusGC = JXCreateGC(display, statusWindow, 0, NULL);
	JXSetFont(display, statusGC, borderFont->fid);
	JXSetBackground(display, statusGC, colors[COLOR_BORDER]);

}

/*************************************************************************
 *************************************************************************/
void UpdateMoveWindow(int x, int y) {
	char str[80];
	unsigned int width;

	JXSetForeground(display, statusGC, colors[COLOR_BORDER]);
	JXFillRectangle(display, statusWindow, statusGC, 0, 0,
		STATUS_WINDOW_WIDTH, statusWindowHeight);

	sprintf(str, "(%d, %d)", x, y);
	width = JXTextWidth(borderFont, str, strlen(str));
	RenderString(statusWindow, statusGC, borderFont, RAMP_INACTIVE,
		STATUS_WINDOW_WIDTH / 2 - width / 2, 2, rootWidth, str);

	JXFlush(display);
}

/*************************************************************************
 *************************************************************************/
void DestroyMoveWindow() {
	if(statusWindow != None) {
		JXFreeGC(display, statusGC);
		JXDestroyWindow(display, statusWindow);
		statusWindow = None;
	}
}

/*************************************************************************
 *************************************************************************/
void CreateResizeWindow() {
	CreateMoveWindow();
}

/*************************************************************************
 *************************************************************************/
void UpdateResizeWindow(int width, int height) {
	char str[80];
	unsigned int fontWidth;

	JXSetForeground(display, statusGC, colors[COLOR_BORDER]);
	JXFillRectangle(display, statusWindow, statusGC, 0, 0,
		STATUS_WINDOW_WIDTH, statusWindowHeight);

	sprintf(str, "%d x %d", width, height);
	fontWidth = JXTextWidth(borderFont, str, strlen(str));
	RenderString(statusWindow, statusGC, borderFont, RAMP_INACTIVE,
		STATUS_WINDOW_WIDTH / 2 - fontWidth / 2, 2, rootWidth, str);

	JXFlush(display);
}

/*************************************************************************
 *************************************************************************/
void DestroyResizeWindow() {
	DestroyMoveWindow();
}

